import { type NextFunction, type Request } from 'express';
import { type Response } from '../Response';
/**
 * Define the interface for a middleware that will be executed before the request handler
 *
 * @typedef BeforeHandlerMiddleware
 * @public
 */
export declare abstract class BeforeHandlerMiddleware {
    /**
     * Abstract definition of the function that will handle the business logic associated with this middleware.
     *
     * @param {import('express').Request} req Express request instance
     * @param {import('express').Response} res express response instance
     * @param {Function} next the next function that will be invoked as part of the express chain
     */
    abstract handle(_req: Request, _res: Response, _next: NextFunction): void;
}
