"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsRequestAdaptor = void 0;
const tslib_1 = require("tslib");
const dino_core_1 = require("dino-core");
const Helper_1 = require("../Helper");
const querystring = tslib_1.__importStar(require("querystring"));
const request_body_parser_1 = require("./request.body.parser");
class AwsRequestAdaptor {
    exposes;
    requestBodyParser;
    constructor(environment) {
        this.requestBodyParser = new request_body_parser_1.RequestBodyParser(environment);
        this.exposes = environment.getOrDefault('dino:server:expose', 'api');
    }
    adapt(message) {
        // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
        return {
            url: this.buildUrl(message),
            method: this.getMethod(message),
            path: Helper_1.Helper.ensureValue(message.path, '/'),
            body: this.requestBodyParser.parse(message),
            headers: this.getHeaders(message),
            query: this.getQuery(message)
        };
    }
    /**
     * Build the request URL if required
     * @param {Object} message the request message
     * @returns {String}
     *
     * @private
     */
    buildUrl(message) {
        if (dino_core_1.ObjectHelper.isDefined(message.url)) {
            return message.url;
        }
        return `${this.getOriginalUrl(message)}`;
    }
    getHeaders(message) {
        const headers = Helper_1.Helper.ensureValue(message.headers, {});
        if (dino_core_1.ObjectHelper.isNotDefined(headers['transfer-encoding'])) {
            headers['transfer-encoding'] = 'identity';
        }
        if (dino_core_1.ObjectHelper.isNotDefined(headers.accept)) {
            headers.accept = 'application/json';
        }
        return headers;
    }
    getOriginalUrl(message) {
        if (message.originalUrl !== undefined) {
            return message.originalUrl;
        }
        const originalUrl = `${Helper_1.Helper.ensureValue(message.resource, '/')}?${querystring.stringify(this.getQuery(message))}`;
        if (!originalUrl.startsWith('/')) {
            return `/${originalUrl}`;
        }
        return originalUrl;
    }
    getMethod(message) {
        const _default = this.exposes.toLowerCase() === 'api' ? 'GET' : 'POST';
        return message.method ?? message.httpMethod ?? _default;
    }
    getQuery(message) {
        return message.multiValueQueryStringParameters ?? message.query ?? message.querystring ?? {};
    }
}
exports.AwsRequestAdaptor = AwsRequestAdaptor;
//# sourceMappingURL=AwsRequestAdaptor.js.map